@@ -12,7 +12,7 @@ class Group(Resource):
         super().__init__(**kwargs)
         self.users = users
 
-    def to_dict(self):
+    def to_dict(self) -> None:
         super().to_dict()
         if (not self.yaml_file) and self.users:
             self.res["users"] = self.users
