@@ -9,7 +9,7 @@ import sys
 from io import StringIO
 from signal import SIGINT, signal
 from types import TracebackType
-from typing import Optional
+from typing import Optional, Any, Dict, List
 
 import kubernetes
 from kubernetes.dynamic import DynamicClient, ResourceInstance
@@ -24,7 +24,7 @@ from kubernetes.dynamic.exceptions import (
 )
 from kubernetes.dynamic.resource import ResourceField
 from packaging.version import Version
-from simple_logger.logger import Any, Dict, List, get_logger, logging
+from simple_logger.logger import get_logger, logging
 from urllib3.exceptions import MaxRetryError
 
 from ocp_resources.constants import (
@@ -274,6 +274,7 @@ class Resource:
         CONFIG_OPENSHIFT_IO = "config.openshift.io"
         CONSOLE_OPENSHIFT_IO = "console.openshift.io"
         COORDINATION_K8S_IO = "coordination.k8s.io"
+        CSIADDONS_OPENSHIFT_IO = "csiaddons.openshift.io"
         DATA_IMPORT_CRON_TEMPLATE_KUBEVIRT_IO = "dataimportcrontemplate.kubevirt.io"
         DISCOVERY_K8S_IO = "discovery.k8s.io"
         EVENTS_K8S_IO = "events.k8s.io"
@@ -325,6 +326,7 @@ class Resource:
         SCHEDULING_K8S_IO = "scheduling.k8s.io"
         SECURITY_ISTIO_IO = "security.istio.io"
         SECURITY_OPENSHIFT_IO = "security.openshift.io"
+        SELF_NODE_REMEDIATION_MEDIK8S_IO = "self-node-remediation.medik8s.io"
         SNAPSHOT_STORAGE_K8S_IO = "snapshot.storage.k8s.io"
         SNAPSHOT_KUBEVIRT_IO = "snapshot.kubevirt.io"
         SRIOVNETWORK_OPENSHIFT_IO = "sriovnetwork.openshift.io"
@@ -438,7 +440,6 @@ class Resource:
         self._set_client_and_api_version()
 
     def _ensure_exists(self) -> None:
-        self.logger.error(self.namespace)
         if not self.exists:
             _name_for_raise = self.name if not self.namespace else f"{self.namespace}/{self.name}"
             raise ResourceNotFoundError(f"Resource `{self.kind}` `{_name_for_raise}` does not exist")
